Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1500)

Unified Diff: device/bluetooth/test/bluetooth_test.h

Issue 2377513004: bluetooth:android: Return the advertised name if advertising (Closed)
Patch Set: Format' Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: device/bluetooth/test/bluetooth_test.h
diff --git a/device/bluetooth/test/bluetooth_test.h b/device/bluetooth/test/bluetooth_test.h
index 9f5468ef7c1fb3b44700ee5aad8d9d434ef945c2..c4494b706460ff7f285e34ad40ad1265bfc021cd 100644
--- a/device/bluetooth/test/bluetooth_test.h
+++ b/device/bluetooth/test/bluetooth_test.h
@@ -44,7 +44,8 @@ class BluetoothTestBase : public testing::Test {
static const std::string kTestAdapterName;
static const std::string kTestAdapterAddress;
- static const std::string kTestDeviceName;
+ static const std::string kTestDeviceGapName;
+ static const std::string kTestDeviceAdvertisedName;
static const std::string kTestDeviceNameEmpty;
static const std::string kTestDeviceAddress1;
@@ -110,13 +111,15 @@ class BluetoothTestBase : public testing::Test {
// Create a fake Low Energy device and discover it.
// |device_ordinal| selects between multiple fake device data sets to produce:
- // 1: Name: kTestDeviceName
+ // 1: Name: kTestDeviceGapName
// Address: kTestDeviceAddress1
+ // TODO(crbug.com/630581): Add Advertised name to macOS.
+ // AdvertisedName: kTestDeviceAdvertisedName
// RSSI: kTestRSSI1
// Advertised UUIDs: {kTestUUIDGenericAccess, kTestUUIDGenericAttribute}
// Service Data: {kTestUUIDHeartRate: [1]}
// Tx Power: kTestTxPower1
- // 2: Name: kTestDeviceName
+ // 2: Name: kTestDeviceGapName
// Address: kTestDeviceAddress1
// RSSI: kTestRSSI2
// Advertised UUIDs: {kTestUUIDImmediateAlert, kTestUUIDLinkLoss}
@@ -141,7 +144,7 @@ class BluetoothTestBase : public testing::Test {
// No Advertised UUIDs
// No Service Data
// No Tx Power
- // 6: Name: kTestDeviceName
+ // 6: Name: kTestDeviceGapName
// Address: kTestDeviceAddress2
// RSSI: kTestRSSI1,
// No Advertised UUIDs
@@ -151,7 +154,8 @@ class BluetoothTestBase : public testing::Test {
virtual BluetoothDevice* SimulateLowEnergyDevice(int device_ordinal);
// Create a fake classic device and discover it. The device will have
// name kTestDeviceName, no advertised UUIDs and address kTestDeviceAddress3.
virtual BluetoothDevice* SimulateClassicDevice();
// Remembers |device|'s platform specific object to be used in a
@@ -151,7 +154,8 @@ class BluetoothTestBase : public testing::Test {
virtual BluetoothDevice* SimulateLowEnergyDevice(int device_ordinal);
// Create a fake classic device and discover it. The device will have
- // name kTestDeviceName, no advertised UUIDs and address kTestDeviceAddress3.
+ // name kTestDeviceGapName, no advertised UUIDs and address
+ // kTestDeviceAddress3.
virtual BluetoothDevice* SimulateClassicDevice();
// Remembers |device|'s platform specific object to be used in a

Powered by Google App Engine
This is Rietveld 408576698